@@ -1366,10 +1366,14 @@ __all__ = [
     "RosTopicProps",
     "Topic",
     "TopicProps",
+    "datasource",
 ]
 
 publication.publish()
 
+# Loading modules to ensure their types are registered with the jsii runtime library
+from . import datasource
+
 def _typecheckingstub__76bc41ab7b9daf0ce6be84e50bfc4775f07407a6bdc4ce895335aa3cdba1a257(
     scope: _ros_cdk_core_7adfd82f.Construct,
     id: builtins.str,
